@@ -7,7 +7,6 @@ from ...combined.combined_league_model import CombinedLeagueModel
 from ...league import League
 from ..espn.epl_espn_league_model import EPLESPNLeagueModel
 from ..oddsportal.epl_oddsportal_league_model import EPLOddsPortalLeagueModel
-from ..sportsdb.epl_sportsdb_league_model import EPLSportsDBLeagueModel
 
 EPL_TEAM_IDENTITY_MAP: dict[str, str] = {}
 EPL_VENUE_IDENTITY_MAP: dict[str, str] = {}
@@ -23,8 +22,8 @@ class EPLCombinedLeagueModel(CombinedLeagueModel):
             League.EPL,
             [
                 EPLESPNLeagueModel(session, position=0),
-                EPLSportsDBLeagueModel(session, position=1),
-                EPLOddsPortalLeagueModel(session, position=2),
+                EPLOddsPortalLeagueModel(session, position=1),
+                # EPLSportsDBLeagueModel(session, position=2),
                 # EPLSportsReferenceLeagueModel(session, position=3),
             ],
             league_filter,
