@@ -126,17 +126,22 @@ def _create_tennisabstract_game_model(
                         ]
                     if "A%" in cols:
                         ace_percentages = [
-                            float(x.replace("%", ""))
+                            float(x.replace("%", "").replace("-", "0.0"))
                             for x in df["A%"].dropna().tolist()
                         ]
                     if "DF%" in cols:
                         double_fault_percentages = [
-                            float(x.replace("%", ""))
+                            float(x.replace("%", "").replace("-", "0.0"))
                             for x in df["DF%"].dropna().tolist()
                         ]
                     if "1stIn" in cols:
                         first_serves_ins = [
-                            float(x.split("(")[0].strip().replace("%", ""))
+                            float(
+                                x.split("(")[0]
+                                .strip()
+                                .replace("%", "")
+                                .replace("-", "0.0")
+                            )
                             for x in df["1stIn"].dropna().tolist()
                         ]
                     if "1st%" in cols:
@@ -426,51 +431,54 @@ def _create_tennisabstract_game_model(
             week=None,
             game_number=None,
             venue=venue,
-            teams=[
-                create_tennisabstract_team_model(
-                    session=session,
-                    dt=dt,
-                    league=league,
-                    player_urls=[x],
-                    ace_percentages=ace_percentages,
-                    double_fault_percentages=double_fault_percentages,
-                    first_serves_ins=first_serves_ins,
-                    first_serve_percentages=first_serve_percentages,
-                    second_serve_percentages=second_serve_percentages,
-                    break_points_saveds=break_points_saveds,
-                    return_points_won_percentages=return_points_won_percentages,
-                    winners=winners,
-                    winners_fronthands=winners_fronthands,
-                    winners_backhands=winners_backhands,
-                    unforced_errors=unforced_errors,
-                    unforced_errors_fronthand=unforced_errors_fronthand,
-                    unforced_errors_backhand=unforced_errors_backhands,
-                    serve_points=serve_points,
-                    serves_won=serves_won,
-                    serves_aces=serves_aces,
-                    serves_unreturned=serves_unreturned,
-                    serves_forced_error_percentage=serves_forced_error_percentage,
-                    serves_won_in_three_shots_or_less=serves_won_in_three_shots_or_less,
-                    serves_wide_percentage=serves_wide_percentage,
-                    serves_body_percentage=serves_body_percentage,
-                    serves_t_percentage=serves_t_percentage,
-                    serves_wide_deuce_percentage=serves_wide_deuce_percentage,
-                    serves_body_deuce_percentage=serves_body_deuce_percentage,
-                    serves_t_deuce_percentage=serves_t_deuce_percentage,
-                    serves_wide_ad_percentage=serves_wide_ad_percentage,
-                    serves_body_ad_percentage=serves_body_ad_percentage,
-                    serves_t_ad_percentage=serves_t_ad_percentage,
-                    serves_net_percentage=serves_net_percentage,
-                    serves_wide_direction_percentage=serves_wide_direction_percentage,
-                    shots_deep_percentage=shots_deep_percentage,
-                    shots_deep_wide_percentage=shots_deep_wide_percentage,
-                    shots_foot_errors_percentage=shots_foot_errors_percentage,
-                    shots_unknown_percentage=shots_unknown_percentage,
-                    points_won_percentage=points_won_percentage,
-                    points=float(points[count]),
-                )
-                for count, x in enumerate(player_urls)
-            ],
+            teams=sorted(
+                [
+                    create_tennisabstract_team_model(
+                        session=session,
+                        dt=dt,
+                        league=league,
+                        player_urls=[x],
+                        ace_percentages=ace_percentages,
+                        double_fault_percentages=double_fault_percentages,
+                        first_serves_ins=first_serves_ins,
+                        first_serve_percentages=first_serve_percentages,
+                        second_serve_percentages=second_serve_percentages,
+                        break_points_saveds=break_points_saveds,
+                        return_points_won_percentages=return_points_won_percentages,
+                        winners=winners,
+                        winners_fronthands=winners_fronthands,
+                        winners_backhands=winners_backhands,
+                        unforced_errors=unforced_errors,
+                        unforced_errors_fronthand=unforced_errors_fronthand,
+                        unforced_errors_backhand=unforced_errors_backhands,
+                        serve_points=serve_points,
+                        serves_won=serves_won,
+                        serves_aces=serves_aces,
+                        serves_unreturned=serves_unreturned,
+                        serves_forced_error_percentage=serves_forced_error_percentage,
+                        serves_won_in_three_shots_or_less=serves_won_in_three_shots_or_less,
+                        serves_wide_percentage=serves_wide_percentage,
+                        serves_body_percentage=serves_body_percentage,
+                        serves_t_percentage=serves_t_percentage,
+                        serves_wide_deuce_percentage=serves_wide_deuce_percentage,
+                        serves_body_deuce_percentage=serves_body_deuce_percentage,
+                        serves_t_deuce_percentage=serves_t_deuce_percentage,
+                        serves_wide_ad_percentage=serves_wide_ad_percentage,
+                        serves_body_ad_percentage=serves_body_ad_percentage,
+                        serves_t_ad_percentage=serves_t_ad_percentage,
+                        serves_net_percentage=serves_net_percentage,
+                        serves_wide_direction_percentage=serves_wide_direction_percentage,
+                        shots_deep_percentage=shots_deep_percentage,
+                        shots_deep_wide_percentage=shots_deep_wide_percentage,
+                        shots_foot_errors_percentage=shots_foot_errors_percentage,
+                        shots_unknown_percentage=shots_unknown_percentage,
+                        points_won_percentage=points_won_percentage,
+                        points=float(points[count]),
+                    )
+                    for count, x in enumerate(player_urls)
+                ],
+                key=lambda x: x.name,
+            ),
             league=str(league),
             year=dt.year,
             season_type=None,
@@ -483,6 +491,7 @@ def _create_tennisabstract_game_model(
             pot=None,
             version=version,
             umpires=[],
+            best_of=None,
         )
     except ValueError as exc:
         logging.warning(str(exc))
